@@ -1,8 +1,6 @@
 """HaVersionLocal class."""
 from dataclasses import dataclass
 
-from pyhaversion.consts import HaVersionSource
-
 from .base import HaVersionBase
 from .consts import LOGGER
 
@@ -16,8 +14,6 @@ except (ModuleNotFoundError, ImportError):
 class HaVersionLocal(HaVersionBase):
     """HaVersionLocal class."""
 
-    source = HaVersionSource.LOCAL
-
     async def fetch(self, **kwargs):
         """Logic to fetch new version data."""
         if localversion is None:
@@ -27,3 +23,8 @@ class HaVersionLocal(HaVersionBase):
     def parse(self):
         """Logic to parse new version data."""
         self._version = self.data
+
+    @property
+    def version_data(self) -> None:
+        """Return extended version data."""
+        return None
